var cs__coal__boundary__conditions_8h =
[
    [ "cs_coal_bc_inlet_t", "structcs__coal__bc__inlet__t.html", "structcs__coal__bc__inlet__t" ],
    [ "cs_coal_bc_inlet_state_t", "cs__coal__boundary__conditions_8h.html#ac19f6ed14d35f677029fe8c4c693444a", null ],
    [ "cs_coal_boundary_conditions", "cs__coal__boundary__conditions_8h.html#a1a0446f88b09d6bac879c95ed37cf312", null ],
    [ "cs_coal_boundary_conditions_density", "cs__coal__boundary__conditions_8h.html#a1a2a0ecd9446527efc7ffd7db57ed3dd", null ],
    [ "cs_coal_boundary_conditions_get_inlet", "cs__coal__boundary__conditions_8h.html#aa2cfa3db8c23df622bc1551bf5ea2e5e", null ],
    [ "cs_coal_boundary_conditions_inlet_set_air_mass_flow_rate_by_func", "cs__coal__boundary__conditions_8h.html#a8c8470d7ae3aebf33e535f59c35d5da3", null ],
    [ "cs_coal_boundary_conditions_inlet_set_air_mass_flow_rate_by_value", "cs__coal__boundary__conditions_8h.html#ac90b758e149d3c69aa804cab48f55809", null ]
];